pub enum MessageType {
JoinRequest,
JoinAccept,
UnconfirmedUp,
ConfirmedUp,
UnconfirmedDown,
ConfirmedDown,
}Expand description
What kind of message a frame is, read from its header.
Variants
JoinRequest
A device asking to join a network.
JoinAccept
A network admitting a device.
UnconfirmedUp
Data from a device that does not need acknowledging.
ConfirmedUp
Data from a device that asks to be acknowledged.
UnconfirmedDown
Data to a device that does not need acknowledging.
ConfirmedDown
Data to a device that asks to be acknowledged.
Implementations